@@ -50,6 +50,9 @@ Dress：连衣裙
 其他数值：默认按1处理。
 建议您使用显著标识来提示结果图使用了 AI 绘画技术，是 AI 生成的图片。
         :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
         :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
 生成图分辨率较大时建议选择 url，使用 base64 可能因图片过大导致返回失败。
         :type RspImgType: str
@@ -58,6 +61,7 @@ Dress：连衣裙
         self._ClothesUrl = None
         self._ClothesType = None
         self._LogoAdd = None
+        self._LogoParam = None
         self._RspImgType = None
 
     @property
@@ -92,6 +96,14 @@ Dress：连衣裙
     def LogoAdd(self, LogoAdd):
         self._LogoAdd = LogoAdd
 
+    @property
+    def LogoParam(self):
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
     @property
     def RspImgType(self):
         return self._RspImgType
@@ -106,6 +118,9 @@ Dress：连衣裙
         self._ClothesUrl = params.get("ClothesUrl")
         self._ClothesType = params.get("ClothesType")
         self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
         self._RspImgType = params.get("RspImgType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -237,12 +252,10 @@ class GenerateAvatarRequest(AbstractModel):
 请在  [百变头像风格列表](https://cloud.tencent.com/document/product/1668/107741) 中选择期望的风格，必须传入风格编号。
         :type Style: str
         :param _InputImage: 输入图 Base64 数据。
-算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
 Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
 图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
         :type InputImage: str
         :param _InputUrl: 输入图 Url。
-算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
 Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
 图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
         :type InputUrl: str
@@ -437,6 +450,14 @@ Strength 值越小，生成图和原图越接近，取值范围(0, 1]，不传
         :type Strength: float
         :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
         :type RspImgType: str
+        :param _EnhanceImage: 画质增强开关，默认关闭。
+1：开启
+0：关闭
+开启后将增强图像的画质清晰度，生成耗时有所增加。
+        :type EnhanceImage: int
+        :param _RestoreFace: 细节优化的面部数量上限，支持0 ~ 6，默认为0。
+若上传大于0的值，将以此为上限对每张图片中面积占比较小的面部进行细节修复，生成耗时根据实际优化的面部个数有所增加。
+        :type RestoreFace: int
         """
         self._InputImage = None
         self._InputUrl = None
@@ -448,6 +469,8 @@ Strength 值越小，生成图和原图越接近，取值范围(0, 1]，不传
         self._LogoParam = None
         self._Strength = None
         self._RspImgType = None
+        self._EnhanceImage = None
+        self._RestoreFace = None
 
     @property
     def InputImage(self):
@@ -529,6 +552,22 @@ Strength 值越小，生成图和原图越接近，取值范围(0, 1]，不传
     def RspImgType(self, RspImgType):
         self._RspImgType = RspImgType
 
+    @property
+    def EnhanceImage(self):
+        return self._EnhanceImage
+
+    @EnhanceImage.setter
+    def EnhanceImage(self, EnhanceImage):
+        self._EnhanceImage = EnhanceImage
+
+    @property
+    def RestoreFace(self):
+        return self._RestoreFace
+
+    @RestoreFace.setter
+    def RestoreFace(self, RestoreFace):
+        self._RestoreFace = RestoreFace
+
 
     def _deserialize(self, params):
         self._InputImage = params.get("InputImage")
@@ -545,6 +584,8 @@ Strength 值越小，生成图和原图越接近，取值范围(0, 1]，不传
             self._LogoParam._deserialize(params.get("LogoParam"))
         self._Strength = params.get("Strength")
         self._RspImgType = params.get("RspImgType")
+        self._EnhanceImage = params.get("EnhanceImage")
+        self._RestoreFace = params.get("RestoreFace")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1123,6 +1164,9 @@ class ReplaceBackgroundRequest(AbstractModel):
         :param _Prompt: 对新背景的文本描述。
 最多支持256个 utf-8 字符，支持中、英文。
         :type Prompt: str
+        :param _Product: 商品图中的商品主体名称。
+建议说明商品主体，否则影响生成效果。
+        :type Product: str
         :param _MaskUrl: 商品 Mask 图 Url，要求背景透明，保留商品主体。
 如果不传，将自动使用内置的商品分割算法得到 Mask。
 支持自定义上传 Mask，如果该参数不为空，则以实际上传的数据为准。
@@ -1147,6 +1191,7 @@ class ReplaceBackgroundRequest(AbstractModel):
         """
         self._ProductUrl = None
         self._Prompt = None
+        self._Product = None
         self._MaskUrl = None
         self._Resolution = None
         self._LogoAdd = None
@@ -1169,6 +1214,14 @@ class ReplaceBackgroundRequest(AbstractModel):
     def Prompt(self, Prompt):
         self._Prompt = Prompt
 
+    @property
+    def Product(self):
+        return self._Product
+
+    @Product.setter
+    def Product(self, Product):
+        self._Product = Product
+
     @property
     def MaskUrl(self):
         return self._MaskUrl
@@ -1213,6 +1266,7 @@ class ReplaceBackgroundRequest(AbstractModel):
     def _deserialize(self, params):
         self._ProductUrl = params.get("ProductUrl")
         self._Prompt = params.get("Prompt")
+        self._Product = params.get("Product")
         self._MaskUrl = params.get("MaskUrl")
         self._Resolution = params.get("Resolution")
         self._LogoAdd = params.get("LogoAdd")
@@ -1316,6 +1370,151 @@ class ResultConfig(AbstractModel):
         
 
 
+class SketchToImageRequest(AbstractModel):
+    """SketchToImage请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Prompt: 用于线稿生图的文本描述。
+最多支持200个 utf-8 字符。
+建议格式：线稿中的主体对象+画面场景+配色/材质/元素/风格等
+        :type Prompt: str
+        :param _InputImage: 线稿图 Base64 数据。
+Base64 和 Url 必须提供一个，如果都提供以Url 为准。
+图片限制：黑白线稿图片，单边分辨率小于5000且大于512（分辨率过小会导致效果受损），转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
+        :type InputImage: str
+        :param _InputUrl: 线稿图 Url。
+Base64 和 Url 必须提供一个，如果都提供以Url 为准。
+图片限制：黑白线稿图片，单边分辨率小于5000且大于512（分辨率过小会导致效果受损），转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
+        :type InputUrl: str
+        :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示结果图使用了 AI 绘画技术，是 AI 生成的图片。
+        :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。生成图分辨率较大时建议选择 url，使用 base64 可能因图片过大导致返回失败。
+        :type RspImgType: str
+        """
+        self._Prompt = None
+        self._InputImage = None
+        self._InputUrl = None
+        self._LogoAdd = None
+        self._LogoParam = None
+        self._RspImgType = None
+
+    @property
+    def Prompt(self):
+        return self._Prompt
+
+    @Prompt.setter
+    def Prompt(self, Prompt):
+        self._Prompt = Prompt
+
+    @property
+    def InputImage(self):
+        return self._InputImage
+
+    @InputImage.setter
+    def InputImage(self, InputImage):
+        self._InputImage = InputImage
+
+    @property
+    def InputUrl(self):
+        return self._InputUrl
+
+    @InputUrl.setter
+    def InputUrl(self, InputUrl):
+        self._InputUrl = InputUrl
+
+    @property
+    def LogoAdd(self):
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def LogoParam(self):
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
+
+    def _deserialize(self, params):
+        self._Prompt = params.get("Prompt")
+        self._InputImage = params.get("InputImage")
+        self._InputUrl = params.get("InputUrl")
+        self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
+        self._RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SketchToImageResponse(AbstractModel):
+    """SketchToImage返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
+        :type ResultImage: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._ResultImage = None
+        self._RequestId = None
+
+    @property
+    def ResultImage(self):
+        return self._ResultImage
+
+    @ResultImage.setter
+    def ResultImage(self, ResultImage):
+        self._ResultImage = ResultImage
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._ResultImage = params.get("ResultImage")
+        self._RequestId = params.get("RequestId")
+
+
 class SubmitDrawPortraitJobRequest(AbstractModel):
     """SubmitDrawPortraitJob请求参数结构体
 
