@@ -38,9 +38,15 @@ FAILEDOPERATION_CREATEORDER = 'FailedOperation.CreateOrder'
 # 创建资源包失败
 FAILEDOPERATION_CREATESOURCEPACKAGEERROR = 'FailedOperation.CreateSourcePackageError'
 
+# 设置备份策略失败，请稍后重试。如果持续不成功，请联系客服进行处理。
+FAILEDOPERATION_CYNOSDBMYSQLSETBACKUPSTRATEGY = 'FailedOperation.CynosdbMysqlSetBackupStrategy'
+
 # 数据库访问失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_DATABASEACCESSERROR = 'FailedOperation.DatabaseAccessError'
 
+# 修改账号权限失败。
+FAILEDOPERATION_DESCRIBEACCOUNTPRIVILEGESERROR = 'FailedOperation.DescribeAccountPrivilegesError'
+
 # 创建流程失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_FLOWCREATEERROR = 'FailedOperation.FlowCreateError'
 
@@ -59,6 +65,9 @@ FAILEDOPERATION_GETOSSINFOERROR = 'FailedOperation.GetOssInfoError'
 # 账号余额不足。
 FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 
+# 修改资源包抵扣优先级失败，请检查参数并稍后重试
+FAILEDOPERATION_MODIFYDEDUCTIONPRIORITYERROR = 'FailedOperation.ModifyDeductionPriorityError'
+
 # 操作失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_OPERATIONFAILEDERROR = 'FailedOperation.OperationFailedError'
 
@@ -74,6 +83,9 @@ FAILEDOPERATION_QUERYSPECBYSPECCODEERROR = 'FailedOperation.QuerySpecBySpecCodeE
 # 资源包退款失败
 FAILEDOPERATION_REFUNDSOURCEPACKAGEERROR = 'FailedOperation.RefundSourcePackageError'
 
+# 修改策略失败。
+FAILEDOPERATION_SERVERLESSSETSTRATEGYERROR = 'FailedOperation.ServerlessSetStrategyError'
+
 # 创建并支付订单失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_TRADECREATEORDERERROR = 'FailedOperation.TradeCreateOrderError'
 
@@ -86,6 +98,9 @@ INTERNALERROR = 'InternalError'
 # 查询数据库失败。
 INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'
 
+# 客户未授权
+INTERNALERROR_GETROLEERROR = 'InternalError.GetRoleError'
+
 # 获取安全组信息失败。
 INTERNALERROR_GETSECURITYGROUPDETAILFAILED = 'InternalError.GetSecurityGroupDetailFailed'
 
@@ -95,6 +110,9 @@ INTERNALERROR_GETSUBNETFAILED = 'InternalError.GetSubnetFailed'
 # 获取VPC失败。
 INTERNALERROR_GETVPCFAILED = 'InternalError.GetVpcFailed'
 
+# 网络错误
+INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
+
 # http请求执行异常。
 INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 
@@ -206,6 +224,9 @@ INVALIDPARAMETERVALUE_PARAMETEROUTRANGEERROR = 'InvalidParameterValue.ParameterO
 # 预付费类型不允许该操作。
 INVALIDPARAMETERVALUE_PREPAYPAYMODEERROR = 'InvalidParameterValue.PrePayPayModeError'
 
+# 找不到该ProjectId
+INVALIDPARAMETERVALUE_PROJECTIDNOTFOUND = 'InvalidParameterValue.ProjectIdNotFound'
+
 # 所选地域和可用区不可用。
 INVALIDPARAMETERVALUE_REGIONZONEUNAVAILABLE = 'InvalidParameterValue.RegionZoneUnavailable'
 
@@ -233,6 +254,9 @@ LIMITEXCEEDED_USERINSTANCELIMIT = 'LimitExceeded.UserInstanceLimit'
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 审计规则不存在
+OPERATIONDENIED_AUDITPOLICYNOTEXISTERROR = 'OperationDenied.AuditPolicyNotExistError'
+
 # 权限校验失败。
 OPERATIONDENIED_CAMDENIEDERROR = 'OperationDenied.CamDeniedError'
 
